============
Installation
============

At the command line::

    $ easy_install django-teryt-tree

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv django-teryt-tree
    $ pip install django-teryt-tree
